@@ -1,5 +1,6 @@
 from ._monkey import patch  # noqa: E402
-from ._monkey import patch_all
+from ._monkey import patch_all  # noqa: E402
+from .internal.utils.deprecations import DDTraceDeprecationWarning  # noqa: E402
 from .pin import Pin  # noqa: E402
 from .settings import _config as config  # noqa: E402
 from .span import Span  # noqa: E402
@@ -20,4 +21,5 @@ __all__ = [
     "tracer",
     "Tracer",
     "config",
+    "DDTraceDeprecationWarning",
 ]
